@@ -10,7 +10,7 @@ import sys
 
 PY2 = sys.version_info[0] == 2
 
-if PY2:
-    range = xrange
+if PY2:  # pragma: no cover
+    range = xrange  # pylint: disable=undefined-variable
 else:
     range = range
