@@ -36,6 +36,15 @@ class attodatetime(object):
         nanosecond=0,
         tzinfo=None,
     ):
+        if not isinstance(year, int):
+            raise TypeError("year must be int")
+
+        if not isinstance(month, int):
+            raise TypeError("month must be int")
+
+        if not isinstance(day, int):
+            raise TypeError("day must be int")
+
         # Create the native date object
         self._native_date = datetime.date(year=year, month=month, day=day)
 
@@ -672,9 +681,9 @@ class attodatetime(object):
             return self.combine(
                 datetime.date.fromordinal(delta.days),
                 attotime(
-                    hour,
-                    minute,
-                    second,
+                    int(hour),
+                    int(minute),
+                    int(second),
                     delta.microseconds,
                     delta.nanoseconds,
                     tzinfo=self.tzinfo,
