@@ -19,6 +19,21 @@ class attotime(object):
         self, hour=0, minute=0, second=0, microsecond=0, nanosecond=0, tzinfo=None
     ):
         # Everything is stored as an integer, except for nanoseconds, which is stored as a Decimal
+        if not isinstance(hour, int):
+            raise TypeError("hour must be int")
+
+        if not isinstance(minute, int):
+            raise TypeError("minute must be int")
+
+        if not isinstance(second, int):
+            raise TypeError("second must be int")
+
+        if not isinstance(microsecond, int):
+            raise TypeError("microsecond must be int")
+
+        if type(nanosecond) not in (int, float, Decimal):
+            raise TypeError("nanosecond must be int, float, or Decimal")
+
         if nanosecond < 0 or nanosecond >= constants.NANOSECONDS_PER_MICROSECOND:
             raise ValueError(
                 "nanosecond must be in 0..{0}".format(
@@ -28,10 +43,7 @@ class attotime(object):
 
         # Create the native time object
         self._native_time = datetime.time(
-            hour=int(hour),
-            minute=int(minute),
-            second=int(second),
-            microsecond=int(microsecond),
+            hour=hour, minute=minute, second=second, microsecond=microsecond,
         )
 
         self._nanosecond = nanosecond
