@@ -27,6 +27,30 @@ class attotimedelta(object):
         weeks=0,
         nanoseconds=0,
     ):
+        if type(days) not in (int, float, Decimal):
+            raise TypeError("days must be int, float, or Decimal")
+
+        if type(seconds) not in (int, float, Decimal):
+            raise TypeError("seconds must be int, float, or Decimal")
+
+        if type(microseconds) not in (int, float, Decimal):
+            raise TypeError("microseconds must be int, float, or Decimal")
+
+        if type(milliseconds) not in (int, float, Decimal):
+            raise TypeError("milliseconds must be int, float, or Decimal")
+
+        if type(minutes) not in (int, float, Decimal):
+            raise TypeError("minutes must be int, float, or Decimal")
+
+        if type(hours) not in (int, float, Decimal):
+            raise TypeError("hours must be int, float, or Decimal")
+
+        if type(weeks) not in (int, float, Decimal):
+            raise TypeError("weeks must be int, float, or Decimal")
+
+        if type(nanoseconds) not in (int, float, Decimal):
+            raise TypeError("nanoseconds must be int, float, or Decimal")
+
         # Convert everything to nanoseconds
         total_nanoseconds = self._as_nanoseconds(
             days=days,
