@@ -16,12 +16,33 @@ from attotime.tests.common import DSTOffset, FixedOffset
 
 
 class TestAttoTimeFunctions(unittest.TestCase):
-    def test_range_check(self):
-        with self.assertRaises(ValueError):
-            attotime(nanosecond=-1)
+    def test_init(self):
+        result = attotime(
+            hour=1, minute=2, second=3, microsecond=4, nanosecond=Decimal("5.67"),
+        )
 
-        with self.assertRaises(ValueError):
-            attotime(nanosecond=constants.NANOSECONDS_PER_MICROSECOND)
+        self.assertEqual(
+            result._native_time,
+            datetime.time(hour=1, minute=2, second=3, microsecond=4),
+        )
+        self.assertEqual(result._nanosecond, Decimal("5.67"))
+        self.assertEqual(result._tzinfo, None)
+
+        result = attotime(
+            hour=1,
+            minute=2,
+            second=3,
+            microsecond=4,
+            nanosecond=5,
+            tzinfo=FixedOffset(1, name="+1"),
+        )
+
+        self.assertEqual(
+            result._native_time,
+            datetime.time(hour=1, minute=2, second=3, microsecond=4),
+        )
+        self.assertEqual(result._nanosecond, 5)
+        self.assertEqual(result._tzinfo, FixedOffset(1, name="+1"))
 
     def test_native_time(self):
         result = attotime(hour=1)
@@ -36,6 +57,29 @@ class TestAttoTimeFunctions(unittest.TestCase):
         result = attotime(microsecond=1)
         self.assertEqual(result._native_time, datetime.time(microsecond=1))
 
+    def test_init_type_check(self):
+        with self.assertRaises(TypeError):
+            attotime(hour=1.2)
+
+        with self.assertRaises(TypeError):
+            attotime(minute=1.2)
+
+        with self.assertRaises(TypeError):
+            attotime(second=1.2)
+
+        with self.assertRaises(TypeError):
+            attotime(microsecond=1.2)
+
+        with self.assertRaises(TypeError):
+            attotime(nanosecond="1.2")
+
+    def test_init_range_check(self):
+        with self.assertRaises(ValueError):
+            attotime(nanosecond=-1)
+
+        with self.assertRaises(ValueError):
+            attotime(nanosecond=constants.NANOSECONDS_PER_MICROSECOND)
+
     def test_hour(self):
         t = attotime(hour=1)
         self.assertEqual(t.hour, 1)
