@@ -15,56 +15,267 @@ from attotime.objects.attotimedelta import attotimedelta
 
 
 class TestAttoTimedeltaFunctions(unittest.TestCase):
-    def test_native_timedelta(self):
+    def test_init(self):
+        result = attotimedelta(weeks=1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(weeks=1))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(weeks=1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(weeks=1.5))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(weeks=-1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(weeks=-1))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(weeks=-1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(weeks=-1.5))
+        self.assertEqual(result._nanoseconds, 0)
+
         result = attotimedelta(days=1)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(days=1))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(days=1.5)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(days=1.5))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(days=-1)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(days=-1))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(days=-1.5)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(days=-1.5))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(hours=1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(hours=1))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(hours=1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(hours=1.5))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(hours=-1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(hours=-1))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(hours=-1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(hours=-1.5))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(minutes=1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(minutes=1))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(minutes=1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(minutes=1.5))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(minutes=-1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(minutes=-1))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(minutes=-1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(minutes=-1.5))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(seconds=1)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(seconds=1))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(seconds=1.5)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(seconds=1.5))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(seconds=-1)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(seconds=-1))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(seconds=-1.5)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(seconds=-1.5))
-
-        result = attotimedelta(microseconds=1)
-        self.assertEqual(result._native_timedelta, datetime.timedelta(microseconds=1))
-
-        result = attotimedelta(microseconds=-1)
-        self.assertEqual(result._native_timedelta, datetime.timedelta(microseconds=-1))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(milliseconds=1)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(milliseconds=1))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(milliseconds=1.5)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(milliseconds=1.5))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(milliseconds=-1)
+
         self.assertEqual(result._native_timedelta, datetime.timedelta(milliseconds=-1))
+        self.assertEqual(result._nanoseconds, 0)
 
         result = attotimedelta(milliseconds=-1.5)
+
         self.assertEqual(
             result._native_timedelta, datetime.timedelta(milliseconds=-1.5)
         )
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(microseconds=1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(microseconds=1))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(microseconds=1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(microseconds=1))
+        self.assertEqual(result._nanoseconds, 500)
+
+        result = attotimedelta(microseconds=-1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(microseconds=-1))
+        self.assertEqual(result._nanoseconds, 0)
+
+        result = attotimedelta(microseconds=-1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta(microseconds=-1))
+        self.assertEqual(result._nanoseconds, -500)
+
+        result = attotimedelta(nanoseconds=1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta())
+        self.assertEqual(result._nanoseconds, 1)
+
+        result = attotimedelta(nanoseconds=1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta())
+        self.assertEqual(result._nanoseconds, 1.5)
+
+        result = attotimedelta(nanoseconds=-1)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta())
+        self.assertEqual(result._nanoseconds, -1)
+
+        result = attotimedelta(nanoseconds=-1.5)
+
+        self.assertEqual(result._native_timedelta, datetime.timedelta())
+        self.assertEqual(result._nanoseconds, -1.5)
+
+        result = attotimedelta(
+            days=1,
+            seconds=2,
+            microseconds=3,
+            milliseconds=4,
+            minutes=5,
+            hours=6,
+            weeks=7,
+            nanoseconds=9,
+        )
 
-        result = attotimedelta(days=1, seconds=2, microseconds=3, milliseconds=4)
         self.assertEqual(
             result._native_timedelta,
-            datetime.timedelta(days=1, seconds=2, microseconds=3, milliseconds=4),
+            datetime.timedelta(
+                days=1,
+                seconds=2,
+                microseconds=3,
+                milliseconds=4,
+                minutes=5,
+                hours=6,
+                weeks=7,
+            ),
         )
+        self.assertEqual(result._nanoseconds, 9)
+
+        result = attotimedelta(
+            nanoseconds=1 * constants.NANOSECONDS_PER_DAY
+            + 2 * constants.NANOSECONDS_PER_SECOND
+            + 3 * constants.NANOSECONDS_PER_MICROSECOND
+            + 4 * constants.NANOSECONDS_PER_MILLISECOND
+            + 5 * constants.NANOSECONDS_PER_MINUTE
+            + 6 * constants.NANOSECONDS_PER_HOUR
+            + 7 * constants.NANOSECONDS_PER_WEEK
+            + 9
+        )
+
+        self.assertEqual(
+            result._native_timedelta,
+            datetime.timedelta(
+                days=1,
+                seconds=2,
+                microseconds=3,
+                milliseconds=4,
+                minutes=5,
+                hours=6,
+                weeks=7,
+            ),
+        )
+        self.assertEqual(result._nanoseconds, 9)
+
+    def test_init_type_check(self):
+        with self.assertRaises(TypeError):
+            attotimedelta(days="1")
+
+        with self.assertRaises(TypeError):
+            attotimedelta(days=None)
+
+        with self.assertRaises(TypeError):
+            attotimedelta(seconds="1")
+
+        with self.assertRaises(TypeError):
+            attotimedelta(seconds=None)
+
+        with self.assertRaises(TypeError):
+            attotimedelta(microseconds="1")
+
+        with self.assertRaises(TypeError):
+            attotimedelta(microseconds=None)
+
+        with self.assertRaises(TypeError):
+            attotimedelta(milliseconds="1")
+
+        with self.assertRaises(TypeError):
+            attotimedelta(milliseconds=None)
+
+        with self.assertRaises(TypeError):
+            attotimedelta(minutes="1")
+
+        with self.assertRaises(TypeError):
+            attotimedelta(minutes=None)
+
+        with self.assertRaises(TypeError):
+            attotimedelta(hours="1")
+
+        with self.assertRaises(TypeError):
+            attotimedelta(hours=None)
+
+        with self.assertRaises(TypeError):
+            attotimedelta(weeks="1")
+
+        with self.assertRaises(TypeError):
+            attotimedelta(weeks=None)
+
+        with self.assertRaises(TypeError):
+            attotimedelta(nanoseconds="1")
+
+        with self.assertRaises(TypeError):
+            attotimedelta(nanoseconds=None)
 
     def test_days(self):
         dt = attotimedelta(days=3)
